[−][src]Module webdav_handler::davpath
Utility module to handle the path part of an URL as a filesytem path.
Structs
| DavPath | Path information relative to a prefix. |
Enums
| ParseError | Error returned by some of the DavPath methods. |
Utility module to handle the path part of an URL as a filesytem path.
| DavPath | Path information relative to a prefix. |
| ParseError | Error returned by some of the DavPath methods. |