[−][src]Struct webdav_handler::async_stream::AsyncStream
An abstraction around a future, where the future can internally loop and yield items.
AsyncStream::new() takes a futures 0.3 Future (async closure, usually) and AsyncStream then implements both a futures 0.1 Stream and a futures 0.3 Stream.
Methods
impl<Item, Error: 'static + Send> AsyncStream<Item, Error>[src]
pub fn new<F, R>(f: F) -> Self where
F: FnOnce(Sender<Item, Error>) -> R,
R: Future03<Output = Result<(), Error>> + Send + 'static,
Item: 'static, [src]
F: FnOnce(Sender<Item, Error>) -> R,
R: Future03<Output = Result<(), Error>> + Send + 'static,
Item: 'static,
Create a new stream from a closure returning a Future 0.3, or an "async closure" (which is the same).
The closure is passed one argument, the sender, which has a method "send" that can be called to send a item to the stream.
The AsyncStream instance that is returned impl's both a futures 0.1 Stream and a futures 0.3 Stream.